typeset library
This supports the input from backend to be formatted with different formatters
Classes
- TypeSet
- WhatsApp like text formatting for you! Format the text with different styles, similar to whatsapp
- TypeSetEditingController
- A custom TextEditingController that provides WhatsApp-style text formatting capabilities in a text input field.
- TypesetReserved
- A class that contains constant variables representing different typesetting elements.
Extensions
- TypeSetExtension on String
- TypeSet extension on String to use typeset method
Functions
-
getTypesetContextMenus(
{required EditableTextState editableTextState, List< StyleTypeEnum> ? styleTypes}) → List<ContextMenuButtonItem> - Generates a list of ContextMenuButtonItems for text editing actions.