TypeSet class
WhatsApp like text formatting for you! Format the text with different styles, similar to whatsapp
Following is the usage: Bold → Hello, World!
Italic → Hello, World!
Strikethrough
→ Hello, World!
Underline → Hello, #World!#
Monospace
→ Hello, World!
Link → google.com|https://google.com
- Inheritance
Constructors
- TypeSet(String inputText, {Key? key, TextStyle? style, TextAlign textAlign = TextAlign.start, TextDirection? textDirection, Locale? locale, bool? softWrap, TextOverflow? overflow, TextScaler? textScaler, int? maxLines, String? semanticsLabel, TextWidthBasis? textWidthBasis, TextHeightBehavior? textHeightBehavior, Color? selectionColor, StrutStyle? strutStyle, GestureRecognizer linkRecognizerBuilder(String linkText, String url)?, TextStyle? linkStyle, TextStyle? monospaceStyle, TextStyle? boldStyle})
-
inputTextis required fieldconst
Properties
- boldStyle → TextStyle?
-
boldStyle is the style of the bold text
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- inputText → String
-
inputText is the text that will be formatted
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- linkRecognizerBuilder → GestureRecognizer Function(String linkText, String url)?
-
linkRecognizerBuilder is the recognizer of the text
final
- linkStyle → TextStyle?
-
linkStyle is the style of the link
final
- locale → Locale?
-
locale is the locale of the text
final
- maxLines → int?
-
maxLines is the max lines of the text
final
- monospaceStyle → TextStyle?
-
monospaceStyle is the style of the monospace text
final
- overflow → TextOverflow?
-
overflow is the overflow of the text
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selectionColor → Color?
-
selectionColor is the selection color of the text
final
- semanticsLabel → String?
-
semanticsLabel is the semantics label of the text
final
- softWrap → bool?
-
softWrap is the soft wrap of the text
final
- strutStyle → StrutStyle?
-
strutStyle is the strut style of the text
final
- style → TextStyle?
-
style is the style of the text
final
- textAlign → TextAlign
-
textAlign is the alignment of the text
final
- textDirection → TextDirection?
-
textDirection is the direction of the text
final
- textHeightBehavior → TextHeightBehavior?
-
textHeightBehavior is the text height behavior of the text
final
- textScaler → TextScaler?
-
textScaler is the text scale factor of the text
final
- textWidthBasis → TextWidthBasis?
-
textWidthBasis is the text width basis of the text
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited